
import { useState } from 'react';
import { Task } from '@/utils/mockData';
import { Badge } from '@/components/ui/badge';
import { Calendar, AlertCircle, Users, CornerDownRight } from 'lucide-react';
import { cn } from '@/lib/utils';
import { 
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";

interface TaskCardProps {
  task: Task;
  onStatusChange: (id: string, status: 'Open' | 'In Progress' | 'Completed') => void;
  onPriorityChange: (id: string, priority: 'High' | 'Medium' | 'Low') => void;
}

const TaskCard = ({ task, onStatusChange, onPriorityChange }: TaskCardProps) => {
  const [isExpanded, setIsExpanded] = useState(false);

  const getPriorityColor = (priority: string) => {
    switch (priority) {
      case 'High':
        return 'bg-red-100 text-red-800 dark:bg-red-900/30 dark:text-red-300 border-red-200 dark:border-red-800/30';
      case 'Medium':
        return 'bg-yellow-100 text-yellow-800 dark:bg-yellow-900/30 dark:text-yellow-300 border-yellow-200 dark:border-yellow-800/30';
      case 'Low':
        return 'bg-green-100 text-green-800 dark:bg-green-900/30 dark:text-green-300 border-green-200 dark:border-green-800/30';
      default:
        return 'bg-gray-100 text-gray-800 dark:bg-gray-900/30 dark:text-gray-300 border-gray-200 dark:border-gray-800/30';
    }
  };

  const getStatusColor = (status: string) => {
    switch (status) {
      case 'Completed':
        return 'bg-green-100 text-green-800 dark:bg-green-900/30 dark:text-green-300 border-green-200 dark:border-green-800/30';
      case 'In Progress':
        return 'bg-blue-100 text-blue-800 dark:bg-blue-900/30 dark:text-blue-300 border-blue-200 dark:border-blue-800/30';
      case 'Open':
        return 'bg-gray-100 text-gray-800 dark:bg-gray-900/30 dark:text-gray-300 border-gray-200 dark:border-gray-800/30';
      default:
        return 'bg-gray-100 text-gray-800 dark:bg-gray-900/30 dark:text-gray-300 border-gray-200 dark:border-gray-800/30';
    }
  };

  const formatDate = (dateString: string) => {
    const date = new Date(dateString);
    return new Intl.DateTimeFormat('en-US', {
      year: 'numeric',
      month: 'short',
      day: 'numeric'
    }).format(date);
  };

  const calculateDaysLeft = (dateString: string) => {
    const today = new Date();
    const deadline = new Date(dateString);
    const diffTime = deadline.getTime() - today.getTime();
    const diffDays = Math.ceil(diffTime / (1000 * 60 * 60 * 24));
    return diffDays;
  };

  const daysLeft = calculateDaysLeft(task.deadline);
  const isUrgent = daysLeft <= 14 && daysLeft > 0;
  const isOverdue = daysLeft < 0;

  return (
    <div className={cn(
      "glass-panel p-5 transition-all duration-300 cursor-pointer hover-lift",
      task.status === 'Completed' && "opacity-70",
      isExpanded && "ring-1 ring-primary/20"
    )}
    onClick={() => setIsExpanded(!isExpanded)}
    >
      <div className="flex flex-col">
        <div className="flex justify-between items-start mb-3">
          <h3 className="font-medium text-base">{task.description}</h3>
          <Badge variant="outline" className={`ml-2 ${getPriorityColor(task.priority)}`}>
            {task.priority}
          </Badge>
        </div>
        
        <div className="flex flex-wrap gap-3 text-sm text-muted-foreground mb-3">
          <div className="flex items-center">
            <Users className="w-4 h-4 mr-1" />
            {task.department}
          </div>
          <div className="flex items-center">
            <Calendar className="w-4 h-4 mr-1" />
            <span className={cn(
              isUrgent && "text-amber-600 dark:text-amber-400",
              isOverdue && "text-red-600 dark:text-red-400"
            )}>
              {formatDate(task.deadline)} 
              {isUrgent && ` (${daysLeft} days left)`}
              {isOverdue && ` (Overdue by ${Math.abs(daysLeft)} days)`}
            </span>
          </div>
        </div>
        
        <div className="flex justify-between items-center">
          <Badge variant="outline" className={getStatusColor(task.status)}>
            {task.status}
          </Badge>
          
          <div className="flex gap-2" onClick={(e) => e.stopPropagation()}>
            <Select 
              defaultValue={task.priority} 
              onValueChange={(value) => onPriorityChange(task.id, value as 'High' | 'Medium' | 'Low')}
            >
              <SelectTrigger className="w-[110px] h-8 text-xs">
                <SelectValue placeholder="Priority" />
              </SelectTrigger>
              <SelectContent>
                <SelectItem value="High">High</SelectItem>
                <SelectItem value="Medium">Medium</SelectItem>
                <SelectItem value="Low">Low</SelectItem>
              </SelectContent>
            </Select>
            
            <Select 
              defaultValue={task.status} 
              onValueChange={(value) => onStatusChange(task.id, value as 'Open' | 'In Progress' | 'Completed')}
            >
              <SelectTrigger className="w-[110px] h-8 text-xs">
                <SelectValue placeholder="Status" />
              </SelectTrigger>
              <SelectContent>
                <SelectItem value="Open">Open</SelectItem>
                <SelectItem value="In Progress">In Progress</SelectItem>
                <SelectItem value="Completed">Completed</SelectItem>
              </SelectContent>
            </Select>
          </div>
        </div>
        
        {isExpanded && (
          <div className="mt-4 pt-4 border-t border-border animate-fade-up">
            <div className="flex items-start gap-2 text-sm text-muted-foreground">
              <CornerDownRight className="w-4 h-4 mt-0.5 shrink-0" />
              <div>
                <p className="font-medium mb-1">Context from Policy:</p>
                <p>{task.context}</p>
              </div>
            </div>
          </div>
        )}
      </div>
    </div>
  );
};

export default TaskCard;
