
import { useState, useEffect } from 'react';
import { Task } from '@/utils/mockData';
import TaskCard from './TaskCard';
import { Input } from '@/components/ui/input';
import { Button } from '@/components/ui/button';
import { Badge } from '@/components/ui/badge';
import { Search, Filter, CheckCircle2, List, X } from 'lucide-react';
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { 
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuCheckboxItem,
  DropdownMenuTrigger
} from "@/components/ui/dropdown-menu";
import { cn } from '@/lib/utils';

interface TaskListProps {
  tasks: Task[];
  onTaskUpdate: (updatedTasks: Task[]) => void;
}

const TaskList = ({ tasks, onTaskUpdate }: TaskListProps) => {
  const [filteredTasks, setFilteredTasks] = useState<Task[]>(tasks);
  const [searchQuery, setSearchQuery] = useState('');
  const [sortBy, setSortBy] = useState('deadline');
  const [filterPriority, setFilterPriority] = useState<string[]>([]);
  const [filterStatus, setFilterStatus] = useState<string[]>([]);
  const [filterDepartment, setFilterDepartment] = useState<string[]>([]);
  const [isFiltering, setIsFiltering] = useState(false);

  const handleStatusChange = (id: string, status: 'Open' | 'In Progress' | 'Completed') => {
    const updatedTasks = tasks.map(task => 
      task.id === id ? { ...task, status } : task
    );
    onTaskUpdate(updatedTasks);
  };

  const handlePriorityChange = (id: string, priority: 'High' | 'Medium' | 'Low') => {
    const updatedTasks = tasks.map(task => 
      task.id === id ? { ...task, priority } : task
    );
    onTaskUpdate(updatedTasks);
  };

  const uniqueDepartments = [...new Set(tasks.map(task => task.department))];

  const sortTasks = (tasksToSort: Task[]) => {
    return [...tasksToSort].sort((a, b) => {
      switch (sortBy) {
        case 'deadline':
          return new Date(a.deadline).getTime() - new Date(b.deadline).getTime();
        case 'priority':
          const priorityOrder = { High: 0, Medium: 1, Low: 2 };
          return priorityOrder[a.priority] - priorityOrder[b.priority];
        case 'department':
          return a.department.localeCompare(b.department);
        default:
          return 0;
      }
    });
  };

  const filterTasks = () => {
    let result = tasks;
    
    // Search filter
    if (searchQuery) {
      result = result.filter(task => 
        task.description.toLowerCase().includes(searchQuery.toLowerCase()) ||
        task.department.toLowerCase().includes(searchQuery.toLowerCase()) ||
        task.context.toLowerCase().includes(searchQuery.toLowerCase())
      );
    }
    
    // Priority filter
    if (filterPriority.length > 0) {
      result = result.filter(task => filterPriority.includes(task.priority));
    }
    
    // Status filter
    if (filterStatus.length > 0) {
      result = result.filter(task => filterStatus.includes(task.status));
    }
    
    // Department filter
    if (filterDepartment.length > 0) {
      result = result.filter(task => filterDepartment.includes(task.department));
    }
    
    // Sort the filtered results
    return sortTasks(result);
  };

  useEffect(() => {
    setFilteredTasks(filterTasks());
    setIsFiltering(
      searchQuery !== '' || 
      filterPriority.length > 0 || 
      filterStatus.length > 0 || 
      filterDepartment.length > 0
    );
  }, [tasks, searchQuery, sortBy, filterPriority, filterStatus, filterDepartment]);

  const clearFilters = () => {
    setSearchQuery('');
    setFilterPriority([]);
    setFilterStatus([]);
    setFilterDepartment([]);
  };

  const completedTasksCount = tasks.filter(task => task.status === 'Completed').length;
  const taskCompletion = Math.round((completedTasksCount / tasks.length) * 100) || 0;
  
  return (
    <div className="w-full max-w-5xl mx-auto">
      <div className="flex flex-col mb-8">
        <div className="flex flex-col lg:flex-row lg:items-center justify-between mb-4 gap-4">
          <div>
            <h2 className="text-2xl font-semibold">Tasks</h2>
            <p className="text-muted-foreground">
              {tasks.length} tasks extracted, {completedTasksCount} completed ({taskCompletion}%)
            </p>
          </div>
          
          <div className="flex flex-col sm:flex-row gap-3">
            <Button variant="outline" className="rounded-full" onClick={clearFilters} 
              disabled={!isFiltering}>
              <CheckCircle2 className="w-4 h-4 mr-2" />
              View All Tasks
            </Button>
            
            <Select value={sortBy} onValueChange={setSortBy}>
              <SelectTrigger className="w-[180px] rounded-full">
                <List className="w-4 h-4 mr-2" />
                <SelectValue placeholder="Sort by" />
              </SelectTrigger>
              <SelectContent>
                <SelectItem value="deadline">Sort by Deadline</SelectItem>
                <SelectItem value="priority">Sort by Priority</SelectItem>
                <SelectItem value="department">Sort by Department</SelectItem>
              </SelectContent>
            </Select>
          </div>
        </div>
        
        <div className="flex flex-col sm:flex-row gap-3 mb-2">
          <div className="relative flex-grow">
            <Search className="absolute left-3 top-1/2 transform -translate-y-1/2 text-muted-foreground w-4 h-4" />
            <Input
              placeholder="Search tasks..."
              value={searchQuery}
              onChange={(e) => setSearchQuery(e.target.value)}
              className="pl-9 rounded-full"
            />
            {searchQuery && (
              <button 
                onClick={() => setSearchQuery('')}
                className="absolute right-3 top-1/2 transform -translate-y-1/2 text-muted-foreground hover:text-foreground"
              >
                <X className="w-4 h-4" />
              </button>
            )}
          </div>
          
          <div className="flex gap-2">
            <DropdownMenu>
              <DropdownMenuTrigger asChild>
                <Button variant="outline" className="rounded-full">
                  <Filter className="w-4 h-4 mr-2" />
                  Priority
                  {filterPriority.length > 0 && (
                    <Badge className="ml-2 bg-primary/10 text-primary border-none">
                      {filterPriority.length}
                    </Badge>
                  )}
                </Button>
              </DropdownMenuTrigger>
              <DropdownMenuContent align="end" className="w-40">
                <DropdownMenuCheckboxItem
                  checked={filterPriority.includes('High')}
                  onCheckedChange={(checked) => {
                    if (checked) {
                      setFilterPriority([...filterPriority, 'High']);
                    } else {
                      setFilterPriority(filterPriority.filter(p => p !== 'High'));
                    }
                  }}
                >
                  High
                </DropdownMenuCheckboxItem>
                <DropdownMenuCheckboxItem
                  checked={filterPriority.includes('Medium')}
                  onCheckedChange={(checked) => {
                    if (checked) {
                      setFilterPriority([...filterPriority, 'Medium']);
                    } else {
                      setFilterPriority(filterPriority.filter(p => p !== 'Medium'));
                    }
                  }}
                >
                  Medium
                </DropdownMenuCheckboxItem>
                <DropdownMenuCheckboxItem
                  checked={filterPriority.includes('Low')}
                  onCheckedChange={(checked) => {
                    if (checked) {
                      setFilterPriority([...filterPriority, 'Low']);
                    } else {
                      setFilterPriority(filterPriority.filter(p => p !== 'Low'));
                    }
                  }}
                >
                  Low
                </DropdownMenuCheckboxItem>
              </DropdownMenuContent>
            </DropdownMenu>
            
            <DropdownMenu>
              <DropdownMenuTrigger asChild>
                <Button variant="outline" className="rounded-full">
                  <Filter className="w-4 h-4 mr-2" />
                  Status
                  {filterStatus.length > 0 && (
                    <Badge className="ml-2 bg-primary/10 text-primary border-none">
                      {filterStatus.length}
                    </Badge>
                  )}
                </Button>
              </DropdownMenuTrigger>
              <DropdownMenuContent align="end" className="w-40">
                <DropdownMenuCheckboxItem
                  checked={filterStatus.includes('Open')}
                  onCheckedChange={(checked) => {
                    if (checked) {
                      setFilterStatus([...filterStatus, 'Open']);
                    } else {
                      setFilterStatus(filterStatus.filter(s => s !== 'Open'));
                    }
                  }}
                >
                  Open
                </DropdownMenuCheckboxItem>
                <DropdownMenuCheckboxItem
                  checked={filterStatus.includes('In Progress')}
                  onCheckedChange={(checked) => {
                    if (checked) {
                      setFilterStatus([...filterStatus, 'In Progress']);
                    } else {
                      setFilterStatus(filterStatus.filter(s => s !== 'In Progress'));
                    }
                  }}
                >
                  In Progress
                </DropdownMenuCheckboxItem>
                <DropdownMenuCheckboxItem
                  checked={filterStatus.includes('Completed')}
                  onCheckedChange={(checked) => {
                    if (checked) {
                      setFilterStatus([...filterStatus, 'Completed']);
                    } else {
                      setFilterStatus(filterStatus.filter(s => s !== 'Completed'));
                    }
                  }}
                >
                  Completed
                </DropdownMenuCheckboxItem>
              </DropdownMenuContent>
            </DropdownMenu>
            
            <DropdownMenu>
              <DropdownMenuTrigger asChild>
                <Button variant="outline" className="rounded-full">
                  <Filter className="w-4 h-4 mr-2" />
                  Department
                  {filterDepartment.length > 0 && (
                    <Badge className="ml-2 bg-primary/10 text-primary border-none">
                      {filterDepartment.length}
                    </Badge>
                  )}
                </Button>
              </DropdownMenuTrigger>
              <DropdownMenuContent align="end" className="w-56">
                {uniqueDepartments.map(dept => (
                  <DropdownMenuCheckboxItem
                    key={dept}
                    checked={filterDepartment.includes(dept)}
                    onCheckedChange={(checked) => {
                      if (checked) {
                        setFilterDepartment([...filterDepartment, dept]);
                      } else {
                        setFilterDepartment(filterDepartment.filter(d => d !== dept));
                      }
                    }}
                  >
                    {dept}
                  </DropdownMenuCheckboxItem>
                ))}
              </DropdownMenuContent>
            </DropdownMenu>
          </div>
        </div>
        
        {isFiltering && (
          <div className="flex flex-wrap gap-2 my-3">
            {filterPriority.map(priority => (
              <Badge
                key={`priority-${priority}`}
                variant="outline"
                className={cn(
                  "rounded-full px-3 py-1 cursor-pointer hover:bg-background",
                  priority === 'High' && "bg-red-100/50 dark:bg-red-900/20",
                  priority === 'Medium' && "bg-yellow-100/50 dark:bg-yellow-900/20",
                  priority === 'Low' && "bg-green-100/50 dark:bg-green-900/20"
                )}
                onClick={() => {
                  setFilterPriority(filterPriority.filter(p => p !== priority));
                }}
              >
                {priority} <X className="ml-1 w-3 h-3" />
              </Badge>
            ))}
            
            {filterStatus.map(status => (
              <Badge
                key={`status-${status}`}
                variant="outline"
                className={cn(
                  "rounded-full px-3 py-1 cursor-pointer hover:bg-background",
                  status === 'Completed' && "bg-green-100/50 dark:bg-green-900/20",
                  status === 'In Progress' && "bg-blue-100/50 dark:bg-blue-900/20"
                )}
                onClick={() => {
                  setFilterStatus(filterStatus.filter(s => s !== status));
                }}
              >
                {status} <X className="ml-1 w-3 h-3" />
              </Badge>
            ))}
            
            {filterDepartment.map(dept => (
              <Badge
                key={`dept-${dept}`}
                variant="outline"
                className="rounded-full px-3 py-1 cursor-pointer hover:bg-background"
                onClick={() => {
                  setFilterDepartment(filterDepartment.filter(d => d !== dept));
                }}
              >
                {dept} <X className="ml-1 w-3 h-3" />
              </Badge>
            ))}
            
            {searchQuery && (
              <Badge
                variant="outline"
                className="rounded-full px-3 py-1 cursor-pointer hover:bg-background"
                onClick={() => setSearchQuery('')}
              >
                Search: {searchQuery} <X className="ml-1 w-3 h-3" />
              </Badge>
            )}
            
            <Button
              variant="ghost"
              size="sm"
              className="text-xs h-7 px-2 rounded-full"
              onClick={clearFilters}
            >
              Clear all
            </Button>
          </div>
        )}
      </div>
      
      {filteredTasks.length === 0 ? (
        <div className="p-12 text-center glass-panel">
          <p className="text-lg font-medium">No tasks match your filters</p>
          <p className="text-muted-foreground mt-2">Try adjusting your search or filters</p>
          <Button 
            variant="outline" 
            className="mt-4 rounded-full"
            onClick={clearFilters}
          >
            Clear all filters
          </Button>
        </div>
      ) : (
        <div className="grid grid-cols-1 gap-4">
          {filteredTasks.map((task) => (
            <TaskCard 
              key={task.id} 
              task={task} 
              onStatusChange={handleStatusChange}
              onPriorityChange={handlePriorityChange}
            />
          ))}
        </div>
      )}
    </div>
  );
};

export default TaskList;
