
import { useState, useRef } from 'react';
import { Upload, FileType, FileUp, AlertCircle, Check } from 'lucide-react';
import { Button } from '@/components/ui/button';
import { toast } from 'sonner';

interface UploadSectionProps {
  onUploadComplete: (fileName: string) => void;
}

const UploadSection = ({ onUploadComplete }: UploadSectionProps) => {
  const [isDragging, setIsDragging] = useState(false);
  const [file, setFile] = useState<File | null>(null);
  const [isUploading, setIsUploading] = useState(false);
  const fileInputRef = useRef<HTMLInputElement>(null);

  const handleDragOver = (e: React.DragEvent<HTMLDivElement>) => {
    e.preventDefault();
    setIsDragging(true);
  };

  const handleDragLeave = () => {
    setIsDragging(false);
  };

  const handleDrop = (e: React.DragEvent<HTMLDivElement>) => {
    e.preventDefault();
    setIsDragging(false);
    
    const droppedFile = e.dataTransfer.files[0];
    if (isValidFile(droppedFile)) {
      setFile(droppedFile);
    }
  };

  const handleFileSelect = (e: React.ChangeEvent<HTMLInputElement>) => {
    const selectedFile = e.target.files?.[0];
    if (selectedFile && isValidFile(selectedFile)) {
      setFile(selectedFile);
    }
  };

  const isValidFile = (file: File) => {
    const validTypes = ['application/pdf', 'application/msword', 'application/vnd.openxmlformats-officedocument.wordprocessingml.document'];
    if (!validTypes.includes(file.type)) {
      toast.error("Please upload a PDF or Word document");
      return false;
    }
    if (file.size > 10 * 1024 * 1024) { // 10MB limit
      toast.error("File size exceeds 10MB limit");
      return false;
    }
    return true;
  };

  const handleUpload = async () => {
    if (!file) return;
    
    setIsUploading(true);
    
    // Simulate file upload with a delay
    try {
      await new Promise(resolve => setTimeout(resolve, 2000));
      toast.success(`${file.name} uploaded successfully`);
      onUploadComplete(file.name);
    } catch (error) {
      toast.error("Upload failed. Please try again.");
      console.error("Upload error:", error);
    } finally {
      setIsUploading(false);
    }
  };

  return (
    <div className="w-full max-w-3xl mx-auto">
      <div className="text-center mb-8">
        <h2 className="text-2xl font-semibold mb-2">Upload Your Policy Document</h2>
        <p className="text-muted-foreground">Upload a PDF or Word document to extract actionable tasks</p>
      </div>
      
      <div 
        className={`
          glass-panel p-8 
          border-2 border-dashed 
          flex flex-col items-center justify-center
          transition-all duration-300
          ${isDragging ? 'border-primary bg-primary/5' : 'border-border'}
          ${file ? 'border-green-500/30 bg-green-50/30 dark:bg-green-900/10' : ''}
        `}
        onDragOver={handleDragOver}
        onDragLeave={handleDragLeave}
        onDrop={handleDrop}
      >
        <input
          type="file"
          ref={fileInputRef}
          onChange={handleFileSelect}
          className="hidden"
          accept=".pdf,.doc,.docx"
        />
        
        {!file ? (
          <>
            <div className="w-16 h-16 bg-primary/10 rounded-full flex items-center justify-center mb-4">
              <Upload className="w-8 h-8 text-primary" />
            </div>
            <h3 className="text-lg font-medium mb-2">Drag and drop your file here</h3>
            <p className="text-sm text-muted-foreground mb-6 max-w-md text-center">
              Support for PDF and Word documents up to 10MB
            </p>
            <Button 
              onClick={() => fileInputRef.current?.click()}
              variant="outline"
              className="rounded-full"
            >
              <FileUp className="w-4 h-4 mr-2" />
              Browse Files
            </Button>
          </>
        ) : (
          <div className="w-full">
            <div className="flex items-center justify-center mb-6">
              <div className="w-12 h-12 bg-green-100 dark:bg-green-900/20 rounded-full flex items-center justify-center">
                <FileType className="w-6 h-6 text-green-600 dark:text-green-400" />
              </div>
            </div>
            <div className="text-center mb-6">
              <h3 className="text-lg font-medium mb-1 flex items-center justify-center">
                {file.name}
                <Check className="w-4 h-4 text-green-500 ml-2" />
              </h3>
              <p className="text-sm text-muted-foreground">
                {(file.size / 1024 / 1024).toFixed(2)} MB
              </p>
            </div>
            <div className="flex justify-center space-x-3">
              <Button
                variant="outline"
                size="sm"
                className="rounded-full"
                onClick={() => {
                  setFile(null);
                  if (fileInputRef.current) {
                    fileInputRef.current.value = '';
                  }
                }}
              >
                Change
              </Button>
              <Button 
                onClick={handleUpload} 
                disabled={isUploading}
                size="sm"
                className="rounded-full min-w-24"
              >
                {isUploading ? 'Processing...' : 'Analyze Document'}
              </Button>
            </div>
          </div>
        )}
      </div>
      
      <div className="mt-4 text-center text-sm text-muted-foreground flex items-center justify-center">
        <AlertCircle className="w-4 h-4 mr-2" />
        Your documents are processed securely and never stored permanently
      </div>
    </div>
  );
};

export default UploadSection;
