
import { useState } from 'react';
import Header from '@/components/Header';
import UploadSection from '@/components/UploadSection';
import TaskList from '@/components/TaskList';
import ExportOptions from '@/components/ExportOptions';
import { Task, generateTasks } from '@/utils/mockData';
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { AlertCircle } from 'lucide-react';
import { toast } from 'sonner';

const Dashboard = () => {
  const [uploadCompleted, setUploadCompleted] = useState(false);
  const [documentName, setDocumentName] = useState('');
  const [tasks, setTasks] = useState<Task[]>([]);

  const handleUploadComplete = (fileName: string) => {
    // Simulate task extraction with a delay
    setTimeout(() => {
      const extractedTasks = generateTasks(fileName);
      setTasks(extractedTasks);
      setDocumentName(fileName);
      setUploadCompleted(true);
      
      toast.success(`${extractedTasks.length} tasks extracted successfully`, {
        description: 'Tasks are now ready for review and prioritization'
      });
    }, 1500);
  };

  const handleTaskUpdate = (updatedTasks: Task[]) => {
    setTasks(updatedTasks);
  };

  return (
    <div className="min-h-screen flex flex-col">
      <Header />
      
      <main className="flex-grow pt-20">
        <div className="container mx-auto px-4 sm:px-6 lg:px-8 py-8">
          <Tabs defaultValue="upload" className="w-full">
            <div className="flex justify-center mb-8">
              <TabsList className="rounded-full h-12">
                <TabsTrigger value="upload" className="rounded-full px-6">
                  Upload Document
                </TabsTrigger>
                <TabsTrigger 
                  value="tasks" 
                  className="rounded-full px-6"
                  disabled={!uploadCompleted}
                  onClick={() => {
                    if (!uploadCompleted) {
                      toast.error("Please upload a document first");
                    }
                  }}
                >
                  Review Tasks
                </TabsTrigger>
                <TabsTrigger 
                  value="export" 
                  className="rounded-full px-6"
                  disabled={!uploadCompleted}
                  onClick={() => {
                    if (!uploadCompleted) {
                      toast.error("Please upload a document first");
                    }
                  }}
                >
                  Export
                </TabsTrigger>
              </TabsList>
            </div>
            
            <TabsContent value="upload" className="mt-0 focus-visible:outline-none focus-visible:ring-0">
              <UploadSection onUploadComplete={handleUploadComplete} />
              
              {uploadCompleted && (
                <div className="flex justify-center mt-6">
                  <div className="glass-panel px-4 py-2 text-sm flex items-center">
                    <AlertCircle className="w-4 h-4 mr-2 text-green-500" />
                    Document processed successfully! Continue to Review Tasks.
                  </div>
                </div>
              )}
            </TabsContent>
            
            <TabsContent value="tasks" className="mt-0 focus-visible:outline-none focus-visible:ring-0">
              {uploadCompleted ? (
                <>
                  <div className="mb-8 text-center">
                    <div className="mb-2 text-sm font-medium text-muted-foreground">
                      Extracted tasks from
                    </div>
                    <h3 className="text-xl font-semibold">{documentName}</h3>
                  </div>
                  <TaskList tasks={tasks} onTaskUpdate={handleTaskUpdate} />
                </>
              ) : (
                <div className="text-center p-12">
                  <p className="text-muted-foreground">Please upload a document first</p>
                </div>
              )}
            </TabsContent>
            
            <TabsContent value="export" className="mt-0 focus-visible:outline-none focus-visible:ring-0">
              {uploadCompleted ? (
                <div className="max-w-3xl mx-auto text-center">
                  <div className="mb-8">
                    <h3 className="text-2xl font-semibold mb-2">Export Task List</h3>
                    <p className="text-muted-foreground">
                      Download your tasks to share with your team or import into your project management tool
                    </p>
                  </div>
                  
                  <div className="glass-panel p-8 mb-8">
                    <div className="text-left mb-6">
                      <h4 className="font-medium mb-1">Export Summary</h4>
                      <ul className="text-sm text-muted-foreground space-y-1">
                        <li>Document: {documentName}</li>
                        <li>Total Tasks: {tasks.length}</li>
                        <li>Open Tasks: {tasks.filter(t => t.status === 'Open').length}</li>
                        <li>In Progress Tasks: {tasks.filter(t => t.status === 'In Progress').length}</li>
                        <li>Completed Tasks: {tasks.filter(t => t.status === 'Completed').length}</li>
                        <li>High Priority Tasks: {tasks.filter(t => t.priority === 'High').length}</li>
                      </ul>
                    </div>
                    
                    <ExportOptions tasks={tasks} />
                  </div>
                  
                  <p className="text-sm text-muted-foreground mt-4">
                    Need to make changes? Go back to the <TabsTrigger value="tasks" className="text-primary underline bg-transparent p-0 h-auto">Review Tasks</TabsTrigger> tab.
                  </p>
                </div>
              ) : (
                <div className="text-center p-12">
                  <p className="text-muted-foreground">Please upload a document first</p>
                </div>
              )}
            </TabsContent>
          </Tabs>
        </div>
      </main>
      
      <footer className="bg-muted/30 py-6">
        <div className="container mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex flex-col sm:flex-row justify-between items-center gap-4">
            <div className="text-sm text-muted-foreground">
              © 2024 SecuPolicy. All rights reserved.
            </div>
            <div className="flex space-x-6">
              <a href="#" className="text-sm text-muted-foreground hover:text-foreground transition-colors">
                Privacy Policy
              </a>
              <a href="#" className="text-sm text-muted-foreground hover:text-foreground transition-colors">
                Terms of Service
              </a>
              <a href="#" className="text-sm text-muted-foreground hover:text-foreground transition-colors">
                Contact
              </a>
            </div>
          </div>
        </div>
      </footer>
    </div>
  );
};

export default Dashboard;
